from typing import Any, Optional

class Model:
    pk: Optional[int]

CharField: Any
BooleanField: Any
ForeignKey: Any
TextField: Any
SlugField: Any
IntegerField: Any
ManyToManyField: Any
DateTimeField: Any

CASCADE: Any
